==> neuro_pypes-1.0.1.tar.gz: neuro_pypes-1.0.1/setup.py <==
#!/usr/bin/env python

"""
pypes
-----

Reusable neuroimaging pipelines using nipype
"""

from __future__ import print_function

import os.path as op
import io
import sys

from   setuptools              import setup, find_packages
from   setuptools.command.test import test as TestCommand


# long description
def read(*filenames, **kwargs):
    encoding = kwargs.get('encoding', 'utf-8')
    sep = kwargs.get('sep', '\n')
    buf = []
    for filename in filenames:
        with io.open(filename, encoding=encoding) as f:
            buf.append(f.read())
    return sep.join(buf)


# Get version without importing, which avoids dependency issues
MODULE_NAME = find_packages(exclude=['tests'])[0]
VERSION_PYFILE = op.join(MODULE_NAME, 'version.py')
# set __version__ variable
exec(compile(read(VERSION_PYFILE), VERSION_PYFILE, 'exec'))

dependencies = read('requirements.txt').split()
requires = [dep for dep in dependencies if not dep.startswith(('git', 'http'))]
links = [dep for dep in dependencies if dep.startswith(('git', 'http'))]
requires += [req.split('#egg=')[1] for req in links]

LICENSE = 'Apache License, Version 2.0'


setup_dict = dict(
    name=MODULE_NAME,
    version=__version__,
    description='Reusable and configurable neuroimaging pipelines with Nipype.',

    license=LICENSE,
    author='Alexandre Savio',
    author_email='alexsavio@gmail.com',
    maintainer='',
    maintainer_email='',

    packages=find_packages(),

    install_requires=requires,

    dependency_links=links,

    scripts=[],

    long_description=read('README.md', 'CHANGES.md'),

    platforms='Linux/MacOSX',

    # https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Programming Language :: Python',
        'Development Status :: 4 - Beta',
        'Natural Language :: English',
        'Environment :: Console',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Scientific/Engineering :: Medical Science Apps.',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Operating System :: MacOS',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],

    extras_require={'tests': [],
                    'docs': ['mkdocs',
                             'recommonmark']
                   }
)

# Python3 support keywords
if sys.version_info >= (3,):
    setup_dict['use_2to3'] = False
    setup_dict['convert_2to3_doctests'] = ['']
    setup_dict['use_2to3_fixers'] = ['']


class PyTest(TestCommand):
    user_options = [('pytest-args=', 'a', "Arguments to pass to py.test")]

    def initialize_options(self):
        TestCommand.initialize_options(self)
        #self.pytest_args = []

    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_suite = True

    def run_tests(self):
        # import here, cause outside the eggs aren't loaded
        import pytest
        errno = pytest.main(self.pytest_args)
        sys.exit(errno)

if __name__ == '__main__':
    setup(**setup_dict)

==> neuro_pypes-1.1.0.tar.gz: neuro_pypes-1.1.0/setup.py <==
#!/usr/bin/env python
"""
pypes
-----

Reusable neuroimaging pipelines using nipype
"""
import io

from setuptools import setup, find_packages

requirements = [
    'scipy>=1.0.0',
    'hansel>=2.0.1',
    'scikit_learn>=0.19.1',
    'matplotlib==2.1.0',
    'nilearn>=0.4.0',
    'kaptan==0.5.9',
    'nibabel>=2.2.1',
    'nipype>=0.14.0',
    'boyle>=0.2.0',
    'pandas>=0.22.0',
    'click>=6.7',
    'nipy>=0.4.2',
    'pydicom>=1.0.1',
]


# long description
def read(*filenames, **kwargs):
    encoding = kwargs.get('encoding', 'utf-8')
    sep = kwargs.get('sep', '\n')
    buf = []
    for filename in filenames:
        with io.open(filename, encoding=encoding) as f:
            buf.append(f.read())
    return sep.join(buf)


setup_dict = dict(
    name='neuro_pypes',
    version='1.1.0',
    description='Reusable and configurable neuroimaging pipelines with Nipype.',
    license='Apache License, Version 2.0',
    author='Alexandre Savio',
    author_email='alexsavio@gmail.com',
    maintainer='',
    maintainer_email='',
    packages=find_packages(exclude=['tests']),
    install_requires=requirements,
    scripts=[],
    entry_points='''
      [console_scripts]
      nitap=neuro_pypes.cli:cli
      ''',
    long_description=read('README.md', 'CHANGES.md'),
    platforms='Linux/MacOSX',
    classifiers=[
        'Programming Language :: Python',
        'Development Status :: 4 - Beta',
        'Natural Language :: English',
        'Environment :: Console',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Scientific/Engineering :: Medical Science Apps.',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Operating System :: MacOS',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    extras_require={
        'tests': [],
        'docs': ['mkdocs', 'recommonmark']
    }
)

if __name__ == '__main__':
    setup(**setup_dict)
